@@ -1,7 +1,7 @@
 #include "network.h"
 
-Network *Network::me;
-GGZMod *Network::mod;
+Network *Network::me = NULL;
+GGZMod *Network::mod = NULL;
 
 Network::Network()
 : QObject()
@@ -27,9 +27,11 @@ void Network::shutdown()
 	ggzmod_free(mod);
 }
 
-void Network::handle(GGZMod *mod, GGZModEvent e, void *data)
+void Network::handle(GGZMod *mod, GGZModEvent e, const void *data)
 {
-	me->m_fd = *(int*)data;
+	Q_UNUSED(e);
+
+	me->m_fd = *(const int*)data;
 	ggzmod_set_state(mod, GGZMOD_STATE_PLAYING);
 	emit me->signalData();
 }
@@ -49,3 +51,8 @@ int Network::cfd()
 	return m_cfd;
 }
 
+GGZMod *Network::getMod()
+{
+	return mod;
+}
+
