@@ -1,23 +1,28 @@
 //////////////////////////////////////////////////////////////////////
 // KTicTacTux
-// Copyright (C) 2001, 2002 Josef Spillner, dr_maux@users.sourceforge.net
+// Copyright (C) 2001 - 2006 Josef Spillner <josef@ggzgamingzone.org>
 // Published under GNU GPL conditions
 //////////////////////////////////////////////////////////////////////
 
 #ifndef KTICTACTUX_PROTO_H
 #define KTICTACTUX_PROTO_H
 
-#include <ggzmod.h>
+#include <qobject.h>
 
 // Forward declarations
-class KTicTacTux;
+namespace KGGZMod
+{
+	class Module;
+};
+
+class KGGZPacket;
 
 // Generic TicTacToe client protocol handler
 class KTicTacTuxProto
 {
 	public:
 		// Constructor
-		KTicTacTuxProto(KTicTacTux *game);
+		KTicTacTuxProto();
 		// Destructor
 		~KTicTacTuxProto();
 
@@ -69,36 +74,33 @@ class KTicTacTuxProto
 		};
 
 		// A winner, if any
-		char winner;
+		Q_INT8 winner;
+		// Holds a move
+		int move;
 
-		// Game socket
-		int fd;
-		// Game control socket
-		int fdcontrol;
-		// Seat number
-		int num;
 		// Both seats
 		int seats[2];
 		// Both names
-		char names[2][17];
+		char *names[2];
+		// Own seat number sent by game server
+		int seatnum;
 
 		// The board representation
 		BoardOwners board[3][3];
 		// The current game state
 		States state;
-		// Holds a move
-		int move;
 		// The player who is on
-		char turn;
+		Q_INT8 turn;
+
 		// Statistics
-		int stats[2];
+		bool stats_record;
+		int stats_wins;
+		int stats_losses;
+		int stats_ties;
+		int stats_forfeits;
 
-		// Connect to the socket
-		void connect();
 		// Initialize protocol
 		void init();
-		// Shutdown game
-		void shutdown();
 
 		// Read opcode
 		int getOp();
@@ -123,21 +125,14 @@ class KTicTacTuxProto
 		int sendMyMove();
 		// Synchronize game
 		void sendSync();
-		// Fetch statistics
-		void sendStatistics();
 
-		// GGZMod object
-		GGZMod *mod;
-		// Game object
-		KTicTacTux *gameobject;
-		// Self object
-		static KTicTacTuxProto *self;
+		// GGZ game module object
+		KGGZMod::Module *mod;
+		// GGZ packet reader
+		KGGZPacket *packet;
 
-		// Callback for control channel
-		static void handle_server(GGZMod *mod, GGZModEvent e,
-					  const void *data);
-		// Dispatch loop
-		void dispatch();
+		// Seat number
+		int num();
 };
 
 #endif
